
.. .. image:: https://readthedocs.org/projects/aws_console_url/badge/?version=latest
    :target: https://aws_console_url.readthedocs.io/index.html
    :alt: Documentation Status

..  .. image:: https://github.com/MacHu-GWU/aws_console_url-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/aws_console_url-project/actions?query=workflow:CI

..  .. image:: https://codecov.io/gh/MacHu-GWU/aws_console_url-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/aws_console_url-project

.. image:: https://img.shields.io/pypi/v/aws_console_url.svg
    :target: https://pypi.python.org/pypi/aws_console_url

.. image:: https://img.shields.io/pypi/l/aws_console_url.svg
    :target: https://pypi.python.org/pypi/aws_console_url

.. image:: https://img.shields.io/pypi/pyversions/aws_console_url.svg
    :target: https://pypi.python.org/pypi/aws_console_url

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/aws_console_url-project

------


..  .. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://aws_console_url.readthedocs.io/index.html

..  .. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://aws_console_url.readthedocs.io/py-modindex.html

..  .. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
    :target: https://aws_console_url.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/aws_console_url-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/aws_console_url-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/aws_console_url-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/aws_console_url#files


Welcome to ``aws_console_url`` Documentation
==============================================================================
``aws_console_url`` allow you to generate AWS console URL for debugging. For quick start, you can check this `Jupyter Notebook <https://github.com/MacHu-GWU/aws_console_url-project/blob/main/usage-examples.ipynb>`_. Also, you can find the full list of public api in `Public API Full List <https://github.com/MacHu-GWU/aws_console_url-project/blob/main/Public-API.rst>`_


.. _install:

Install
------------------------------------------------------------------------------

``aws_console_url`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install aws_console_url

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade aws_console_url